@@ -19,7 +19,7 @@
 #' @return A data frame. Returns NULL if no connection.
 #'
 #' @importFrom httr2 req_headers req_url_path_append req_url_query req_retry req_perform resp_body_json
-#' @importFrom dplyr filter pull as_tibble
+#' @importFrom dplyr filter pull as_tibble left_join select
 #' @importFrom curl has_internet
 #'
 #' @seealso \code{\link{bfs_get_data}}
@@ -100,33 +100,65 @@ bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search
     return(df_final)
   }
   
-  df_links <- df$links[[1]] %>%
-    as_tibble()
-  
-  url_asset <- df_links %>%
-    filter(rel == "self") %>%
-    pull(href)
-  
-  url_px <- df_links %>%
-    filter(rel == "related") %>%
-    pull(href)
-  
-  url_structure_json <- df_links %>%
-    filter(rel == "related-further") %>%
-    pull(href)
-  
-  number_asset <- basename(url_asset)
   language_available <- strsplit(tolower(df$description$language), split = "/")
   
-  df_final <- dplyr::tibble(
+  df_catalog_metadata <- dplyr::tibble(
     title = df$description$titles$main,
     language = language,
     publication_date = as.Date(df$bfs$embargo),
-    number_asset = number_asset,
     order_nr = df$shop$orderNr,
-    url_px = url_px,
     language_available = language_available,
-    url_structure_json = url_structure_json
+    damId = df$ids$damId
   )
+  
+  get_catalog_links_metadata <- function(i) {
+    
+    damId <- df$ids$damId[i]
+    
+    df_links <- df$links[[i]] %>%
+      as_tibble()
+    
+    if(nrow(df_links) == 0) {
+      df_links_cleaned <- dplyr::tibble(
+        number_asset = NA_character_,
+        url_px = NA_character_,
+        url_structure_json = NA_character_,
+        damId = damId
+      )
+      return(df_links_cleaned)
+    }
+    
+    url_asset <- df_links %>%
+      filter(rel == "self") %>%
+      pull(href)
+    
+    url_px <- df_links %>%
+      filter(rel == "related") %>%
+      pull(href)
+    
+    url_structure_json <- df_links %>%
+      filter(rel == "related-further") %>%
+      pull(href)
+    
+    number_asset <- basename(url_asset)
+
+    df_links_cleaned <- dplyr::tibble(
+      number_asset = number_asset[1],
+      url_px = url_px[1],
+      url_structure_json = url_structure_json[1],
+      damId = damId
+    )
+    return(df_links_cleaned)
+  }
+  
+  df_catalog_links_metadata <- purrr::map_dfr(
+    .x = seq_along(df$links), 
+    .f = get_catalog_links_metadata
+  )
+  
+  df_final <- df_catalog_metadata |>
+    left_join(df_catalog_links_metadata, by = "damId") |>
+    select(title, language, number_asset, publication_date, order_nr, url_px, language_available, url_structure_json, damId)
+  
   return(df_final)
 }
